@@ -1,8 +1,17 @@
-pub use clouseau_core::*;
 #[cfg(feature = "derive")]
 pub use clouseau_macros::Queryable;
+
 #[cfg(feature = "parser_pest")]
 pub use clouseau_pest::parse_query;
+
+#[cfg(feature = "query")]
+pub use clouseau_query::{Context, Query};
+
+#[cfg(feature = "query")]
 pub mod query {
     pub use clouseau_query::*;
 }
+
+pub mod core {
+    pub use clouseau_core::*;
+}
