@@ -1,7 +1,8 @@
 use clouseau::query::Context;
 use clouseau::*;
 use std::collections::*;
-use velcro::*;
+use std::string::ToString;
+use velcro::{vec, *};
 
 #[test]
 fn map_with_composite_keys() {
@@ -13,7 +14,7 @@ fn map_with_composite_keys() {
     };
     let ctx = Context::default();
     let q = parse_query(r#" ./key:{8, "def", 4} "#).unwrap();
-    let mut result: Vec<Value> = ctx.exec(&q, &t).collect();
+    let mut result: Vec<String> = ctx.exec(&q, &t).map(|v| v.to_string()).collect();
     result.sort();
-    assert_eq!(result, vec_from![4]);
+    assert_eq!(result, vec![String::from("4")]);
 }
